==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/elementpackaging/impl/PackageReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.elementpackaging.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.elementpackaging.EP_PKGSet;
import io.ciera.tool.sql.ooaofooa.elementpackaging.PackageReference;
import io.ciera.tool.sql.ooaofooa.elementpackaging.PackageReferenceSet;
import io.ciera.tool.sql.ooaofooa.elementpackaging.impl.EP_PKGSetImpl;

import java.util.Arrays;
import java.util.List;


public class PackageReferenceSetImpl extends InstanceSet<PackageReferenceSet,PackageReference> implements PackageReferenceSet {

    // attributes
    @Override
    public void setReferred_Package_ID( UniqueId ref_Referred_Package_ID ) throws XtumlException {
        for ( PackageReference packagereference : this ) packagereference.setReferred_Package_ID( ref_Referred_Package_ID );
    }
    @Override
    public void setReferring_Package_ID( UniqueId ref_Referring_Package_ID ) throws XtumlException {
        for ( PackageReference packagereference : this ) packagereference.setReferring_Package_ID( ref_Referring_Package_ID );
    }


    // selections
    @Override
    public EP_PKGSet R1402_is_referenced_by_EP_PKG() throws XtumlException {
        EP_PKGSet ep_pkgset = new EP_PKGSetImpl();
        for ( PackageReference packagereference : this ) ep_pkgset.add( packagereference.R1402_is_referenced_by_EP_PKG() );
        return ep_pkgset;
    }
    @Override
    public EP_PKGSet R1402_refers_to_EP_PKG() throws XtumlException {
        EP_PKGSet ep_pkgset = new EP_PKGSetImpl();
        for ( PackageReference packagereference : this ) ep_pkgset.add( packagereference.R1402_refers_to_EP_PKG() );
        return ep_pkgset;
    }


    @Override
    public PackageReference nullElement() {
        return PackageReferenceImpl.EMPTY_PACKAGEREFERENCE;
    }

    @Override
    public PackageReferenceSet emptySet() {
      return new PackageReferenceSetImpl();
    }

    @Override
    public PackageReferenceSet value() {
        return this;
    }

    @Override
    public List<PackageReference> elements() {
        return Arrays.asList(toArray(new PackageReference[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/elementpackaging/impl/PackageReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.elementpackaging.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.elementpackaging.EP_PKGSet;
import io.ciera.tool.sql.ooaofooa.elementpackaging.PackageReference;
import io.ciera.tool.sql.ooaofooa.elementpackaging.PackageReferenceSet;
import io.ciera.tool.sql.ooaofooa.elementpackaging.impl.EP_PKGSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class PackageReferenceSetImpl extends InstanceSet<PackageReferenceSet,PackageReference> implements PackageReferenceSet {

    public PackageReferenceSetImpl() {
    }

    public PackageReferenceSetImpl(Comparator<? super PackageReference> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setReferred_Package_ID( UniqueId ref_Referred_Package_ID ) throws XtumlException {
        for ( PackageReference packagereference : this ) packagereference.setReferred_Package_ID( ref_Referred_Package_ID );
    }
    @Override
    public void setReferring_Package_ID( UniqueId ref_Referring_Package_ID ) throws XtumlException {
        for ( PackageReference packagereference : this ) packagereference.setReferring_Package_ID( ref_Referring_Package_ID );
    }


    // selections
    @Override
    public EP_PKGSet R1402_is_referenced_by_EP_PKG() throws XtumlException {
        EP_PKGSet ep_pkgset = new EP_PKGSetImpl();
        for ( PackageReference packagereference : this ) ep_pkgset.add( packagereference.R1402_is_referenced_by_EP_PKG() );
        return ep_pkgset;
    }
    @Override
    public EP_PKGSet R1402_refers_to_EP_PKG() throws XtumlException {
        EP_PKGSet ep_pkgset = new EP_PKGSetImpl();
        for ( PackageReference packagereference : this ) ep_pkgset.add( packagereference.R1402_refers_to_EP_PKG() );
        return ep_pkgset;
    }


    @Override
    public PackageReference nullElement() {
        return PackageReferenceImpl.EMPTY_PACKAGEREFERENCE;
    }

    @Override
    public PackageReferenceSet emptySet() {
      return new PackageReferenceSetImpl();
    }

    @Override
    public PackageReferenceSet emptySet(Comparator<? super PackageReference> comp) {
      return new PackageReferenceSetImpl(comp);
    }

    @Override
    public PackageReferenceSet value() {
        return this;
    }

    @Override
    public List<PackageReference> elements() {
        return Arrays.asList(toArray(new PackageReference[0]));
    }

}
